@@ -25,12 +25,26 @@ from apps.packages import PackageService
 from superdesk import get_resource_service
 from superdesk.errors import SuperdeskApiError
 from superdesk.metadata.utils import aggregations
-from superdesk.metadata.item import CONTENT_TYPE, ITEM_TYPE, not_analyzed, GUID_FIELD, ITEM_STATE, CONTENT_STATE, \
-    PUB_STATUS
+from superdesk.metadata.item import (
+    CONTENT_TYPE,
+    ITEM_TYPE,
+    not_analyzed,
+    GUID_FIELD,
+    ITEM_STATE,
+    CONTENT_STATE,
+    PUB_STATUS,
+)
 from superdesk.metadata.packages import LINKED_IN_PACKAGES, PACKAGE, MAIN_GROUP, RESIDREF
 from superdesk.notification import push_notification
-from apps.archive.common import get_user, item_schema, is_genre, BROADCAST_GENRE, ITEM_OPERATION, is_item_in_package, \
-    insert_into_versions
+from apps.archive.common import (
+    get_user,
+    item_schema,
+    is_genre,
+    BROADCAST_GENRE,
+    ITEM_OPERATION,
+    is_item_in_package,
+    insert_into_versions,
+)
 from apps.archive.archive import SOURCE as ARCHIVE
 import superdesk
 from superdesk.services import BaseService
@@ -40,65 +54,55 @@ from apps.publish.content import KillPublishService, TakeDownPublishService
 from flask_babel import _
 
 logger = logging.getLogger(__name__)
-PACKAGE_TYPE = 'package_type'
-TAKES_PACKAGE = 'takes'
-SEQUENCE = 'sequence'
-LAST_TAKE = 'last_take'
+PACKAGE_TYPE = "package_type"
+TAKES_PACKAGE = "takes"
+SEQUENCE = "sequence"
+LAST_TAKE = "last_take"
 
 
 class ArchivedResource(Resource):
     datasource = {
-        'search_backend': 'elastic',
-        'aggregations': aggregations,
-        'default_sort': [('_updated', -1)],
-        'elastic_filter_callback': get_content_filter,
-        'projection': {
-            'old_version': 0,
-            'last_version': 0
-        }
+        "search_backend": "elastic",
+        "aggregations": aggregations,
+        "default_sort": [("_updated", -1)],
+        "elastic_filter_callback": get_content_filter,
+        "projection": {"old_version": 0, "last_version": 0},
     }
 
-    mongo_prefix = 'ARCHIVED'
+    mongo_prefix = "ARCHIVED"
 
     extra_fields = published_item_fields.copy()
     # item_id + _current_version will be used fetch archived item.
-    extra_fields['archived_id'] = {
-        'type': 'string',
-        'mapping': not_analyzed
-    }
+    extra_fields["archived_id"] = {"type": "string", "mapping": not_analyzed}
 
     schema = item_schema(extra_fields)
-    resource_methods = ['GET']
-    item_methods = ['GET', 'PATCH', 'DELETE']
-    privileges = {'PATCH': 'archived', 'DELETE': 'archived'}
+    resource_methods = ["GET"]
+    item_methods = ["GET", "PATCH", "DELETE"]
+    privileges = {"PATCH": "archived", "DELETE": "archived"}
 
-    additional_lookup = {
-        'url': 'regex("[\w,.:-]+")',
-        'field': 'archived_id'
-    }
+    additional_lookup = {"url": 'regex("[\w,.:-]+")', "field": "archived_id"}
 
     mongo_indexes = {
-        'item_id_1': ([('item_id', 1)], {'background': True}),
+        "item_id_1": ([("item_id", 1)], {"background": True}),
     }
 
 
 class ArchivedService(BaseService):
-
     def on_create(self, docs):
         package_service = PackageService()
 
         for doc in docs:
-            doc.pop('lock_user', None)
-            doc.pop('lock_time', None)
-            doc.pop('lock_action', None)
-            doc.pop('lock_session', None)
-            doc.pop('highlights', None)
-            doc.pop('marked_desks', None)
-            doc['archived_id'] = self._get_archived_id(doc.get('item_id'), doc.get(config.VERSION))
+            doc.pop("lock_user", None)
+            doc.pop("lock_time", None)
+            doc.pop("lock_action", None)
+            doc.pop("lock_session", None)
+            doc.pop("highlights", None)
+            doc.pop("marked_desks", None)
+            doc["archived_id"] = self._get_archived_id(doc.get("item_id"), doc.get(config.VERSION))
 
             if doc.get(ITEM_TYPE) == CONTENT_TYPE.COMPOSITE:
                 for ref in package_service.get_item_refs(doc):
-                    ref['location'] = 'archived'
+                    ref["location"] = "archived"
 
     def validate_delete_action(self, doc, allow_all_types=False):
         """Runs on delete of archive item.
@@ -121,20 +125,21 @@ class ArchivedService(BaseService):
         bad_req_error = SuperdeskApiError.badRequestError
 
         id_field = doc[config.ID_FIELD]
-        item_id = doc['item_id']
+        item_id = doc["item_id"]
 
-        doc['item_id'] = id_field
+        doc["item_id"] = id_field
         doc[config.ID_FIELD] = item_id
 
         if not allow_all_types and doc[ITEM_TYPE] != CONTENT_TYPE.TEXT:
-            raise bad_req_error(message=_('Only Text articles are allowed to be Killed in Archived repo'))
+            raise bad_req_error(message=_("Only Text articles are allowed to be Killed in Archived repo"))
 
         if is_genre(doc, BROADCAST_GENRE):
             raise bad_req_error(message=_("Killing of Broadcast Items isn't allowed in Archived repo"))
 
-        if get_resource_service('archive_broadcast').get_broadcast_items_from_master_story(doc, True):
+        if get_resource_service("archive_broadcast").get_broadcast_items_from_master_story(doc, True):
             raise bad_req_error(
-                message=_("Can't kill as this article acts as a Master Story for existing broadcast(s)"))
+                message=_("Can't kill as this article acts as a Master Story for existing broadcast(s)")
+            )
 
         if get_resource_service(ARCHIVE).find_one(req=None, _id=doc[GUID_FIELD]):
             raise bad_req_error(message=_("Can't Kill as article is still available in production"))
@@ -149,9 +154,9 @@ class ArchivedService(BaseService):
 
             req = ParsedRequest()
             req.sort = '[("%s", -1)]' % config.VERSION
-            takes_package = list(self.get(req=req, lookup={'item_id': takes_package_id}))
+            takes_package = list(self.get(req=req, lookup={"item_id": takes_package_id}))
             if not takes_package:
-                raise bad_req_error(message=_('Digital Story of the article not found in Archived repo'))
+                raise bad_req_error(message=_("Digital Story of the article not found in Archived repo"))
 
             takes_package = takes_package[0]
             if not allow_all_types and is_item_in_package(takes_package):
@@ -162,14 +167,14 @@ class ArchivedService(BaseService):
                     if get_resource_service(ARCHIVE).find_one(req=None, _id=takes_ref[RESIDREF]):
                         raise bad_req_error(message=_("Can't Kill as Take(s) are still available in production"))
 
-                    take = list(self.get(req=None, lookup={'item_id': takes_ref[RESIDREF]}))
+                    take = list(self.get(req=None, lookup={"item_id": takes_ref[RESIDREF]}))
                     if not take:
-                        raise bad_req_error(message=_('One of Take(s) not found in Archived repo'))
+                        raise bad_req_error(message=_("One of Take(s) not found in Archived repo"))
 
                     if not allow_all_types and is_item_in_package(take[0]):
                         raise bad_req_error(message=_("Can't kill as one of Take(s) is part of a Package"))
 
-        doc['item_id'] = item_id
+        doc["item_id"] = item_id
         doc[config.ID_FIELD] = id_field
 
     def on_delete(self, doc):
@@ -187,8 +192,12 @@ class ArchivedService(BaseService):
         item = super().find_one(req, **lookup)
         user = get_user()
 
-        if user and item and str(item.get('task', {}).get('stage', '')) in \
-                get_resource_service('users').get_invisible_stages_ids(user.get('_id')):
+        if (
+            user
+            and item
+            and str(item.get("task", {}).get("stage", ""))
+            in get_resource_service("users").get_invisible_stages_ids(user.get("_id"))
+        ):
             raise SuperdeskApiError.forbiddenError(_("User does not have permissions to read the item."))
 
         return item
@@ -217,8 +226,8 @@ class ArchivedService(BaseService):
         """
 
         # Step 1
-        articles_to_kill = self.find_articles_to_kill({'_id': id})
-        logger.info('Fetched articles to kill for id: {}'.format(id))
+        articles_to_kill = self.find_articles_to_kill({"_id": id})
+        logger.info("Fetched articles to kill for id: {}".format(id))
         articles_to_kill.sort(key=itemgetter(ITEM_TYPE), reverse=True)  # Needed because package has to be inserted last
         kill_service = KillPublishService() if updates.get(ITEM_OPERATION) == ITEM_KILL else TakeDownPublishService()
 
@@ -230,31 +239,32 @@ class ArchivedService(BaseService):
             updated.update(updates_copy)
             # Step 2, If it is flagged as archived only it has no related items in the system so can be deleted.
             # An email is sent to all subscribers
-            if original.get('flags', {}).get('marked_archived_only', False):
-                super().delete({'item_id': article['item_id']})
-                logger.info('Delete for article: {}'.format(article[config.ID_FIELD]))
+            if original.get("flags", {}).get("marked_archived_only", False):
+                super().delete({"item_id": article["item_id"]})
+                logger.info("Delete for article: {}".format(article[config.ID_FIELD]))
                 kill_service.broadcast_kill_email(article, updates_copy)
-                logger.info('Broadcast kill email for article: {}'.format(article[config.ID_FIELD]))
+                logger.info("Broadcast kill email for article: {}".format(article[config.ID_FIELD]))
                 continue
 
             # Step 3(i)
             self._remove_and_set_kill_properties(article, articles_to_kill, updated)
-            logger.info('Removing and setting properties for article: {}'.format(article[config.ID_FIELD]))
+            logger.info("Removing and setting properties for article: {}".format(article[config.ID_FIELD]))
 
             # Step 3(ii)
             transmission_details = list(
-                get_resource_service(LEGAL_PUBLISH_QUEUE_NAME).get(req=None,
-                                                                   lookup={'item_id': article['item_id']}))
+                get_resource_service(LEGAL_PUBLISH_QUEUE_NAME).get(req=None, lookup={"item_id": article["item_id"]})
+            )
 
             if transmission_details:
-                get_enqueue_service(updates.get(ITEM_OPERATION, ITEM_KILL)) \
-                    .enqueue_archived_kill_item(article, transmission_details)
+                get_enqueue_service(updates.get(ITEM_OPERATION, ITEM_KILL)).enqueue_archived_kill_item(
+                    article, transmission_details
+                )
 
-            article[config.ID_FIELD] = article.pop('item_id', article['item_id'])
+            article[config.ID_FIELD] = article.pop("item_id", article["item_id"])
 
             # Step 3(iv)
-            super().delete({'item_id': article[config.ID_FIELD]})
-            logger.info('Delete for article: {}'.format(article[config.ID_FIELD]))
+            super().delete({"item_id": article[config.ID_FIELD]})
+            logger.info("Delete for article: {}".format(article[config.ID_FIELD]))
 
             # Step 3(i) - Creating entries in published collection
             docs = [article]
@@ -262,36 +272,37 @@ class ArchivedService(BaseService):
             insert_into_versions(doc=article)
             published_doc = deepcopy(article)
             published_doc[QUEUE_STATE] = PUBLISH_STATE.QUEUED
-            get_resource_service('published').post([published_doc])
-            logger.info('Insert into archive and published for article: {}'.format(article[config.ID_FIELD]))
+            get_resource_service("published").post([published_doc])
+            logger.info("Insert into archive and published for article: {}".format(article[config.ID_FIELD]))
 
             # Step 3(iii)
-            import_into_legal_archive.apply_async(countdown=3, kwargs={'item_id': article[config.ID_FIELD]})
-            logger.info('Legal Archive import for article: {}'.format(article[config.ID_FIELD]))
+            import_into_legal_archive.apply_async(countdown=3, kwargs={"item_id": article[config.ID_FIELD]})
+            logger.info("Legal Archive import for article: {}".format(article[config.ID_FIELD]))
 
             # Step 3(v)
             kill_service.broadcast_kill_email(article, updates_copy)
-            logger.info('Broadcast kill email for article: {}'.format(article[config.ID_FIELD]))
+            logger.info("Broadcast kill email for article: {}".format(article[config.ID_FIELD]))
 
     def on_updated(self, updates, original):
         user = get_user()
-        push_notification('item:deleted:archived', item=str(original[config.ID_FIELD]),
-                          user=str(user.get(config.ID_FIELD)))
+        push_notification(
+            "item:deleted:archived", item=str(original[config.ID_FIELD]), user=str(user.get(config.ID_FIELD))
+        )
 
     def on_fetched_item(self, doc):
-        doc['_type'] = 'archived'
+        doc["_type"] = "archived"
 
     def _get_archived_id(self, item_id, version):
-        return '{}:{}'.format(item_id, version)
+        return "{}:{}".format(item_id, version)
 
     def get_archived_takes_package(self, package_id, take_id, version, include_other_takes=True):
         req = ParsedRequest()
         req.sort = '[("%s", -1)]' % config.VERSION
-        take_packages = list(self.get(req=req, lookup={'item_id': package_id}))
+        take_packages = list(self.get(req=req, lookup={"item_id": package_id}))
 
         for take_package in take_packages:
             for ref in self._get_package_refs(take_package):
-                if ref[RESIDREF] == take_id and (include_other_takes or ref['_current_version'] == version):
+                if ref[RESIDREF] == take_id and (include_other_takes or ref["_current_version"] == version):
                     return take_package
 
     def find_articles_to_kill(self, lookup, include_other_takes=True):
@@ -312,20 +323,19 @@ class ArchivedService(BaseService):
 
         req = ParsedRequest()
         req.sort = '[("%s", -1)]' % config.VERSION
-        archived_doc = list(self.get(req=req, lookup={'item_id': archived_doc['item_id']}))[0]
+        archived_doc = list(self.get(req=req, lookup={"item_id": archived_doc["item_id"]}))[0]
         articles_to_kill = [archived_doc]
         takes_package_id = self._get_take_package_id(archived_doc)
         if takes_package_id:
-            takes_package = self.get_archived_takes_package(takes_package_id,
-                                                            archived_doc['item_id'],
-                                                            archived_doc['_current_version'],
-                                                            include_other_takes)
+            takes_package = self.get_archived_takes_package(
+                takes_package_id, archived_doc["item_id"], archived_doc["_current_version"], include_other_takes
+            )
             articles_to_kill.append(takes_package)
 
             if include_other_takes:
                 for takes_ref in self._get_package_refs(takes_package):
                     if takes_ref[RESIDREF] != archived_doc[GUID_FIELD]:
-                        take = list(self.get(req=req, lookup={'item_id': takes_ref[RESIDREF]}))[0]
+                        take = list(self.get(req=req, lookup={"item_id": takes_ref[RESIDREF]}))[0]
                         articles_to_kill.append(take)
 
         return articles_to_kill
@@ -341,32 +351,33 @@ class ArchivedService(BaseService):
         :type updates: dict
         """
 
-        article.pop('archived_id', None)
-        article.pop('_type', None)
-        article.pop('_links', None)
-        article.pop('queue_state', None)
+        article.pop("archived_id", None)
+        article.pop("_type", None)
+        article.pop("_links", None)
+        article.pop("queue_state", None)
         article.pop(config.ETAG, None)
 
-        for field in ['headline', 'abstract', 'body_html']:
-            article[field] = updates.get(field, article.get(field, ''))
+        for field in ["headline", "abstract", "body_html"]:
+            article[field] = updates.get(field, article.get(field, ""))
 
         article[ITEM_STATE] = CONTENT_STATE.KILLED if updates[ITEM_OPERATION] == ITEM_KILL else CONTENT_STATE.RECALLED
         article[ITEM_OPERATION] = updates[ITEM_OPERATION]
-        article['pubstatus'] = PUB_STATUS.CANCELED
+        article["pubstatus"] = PUB_STATUS.CANCELED
         article[config.LAST_UPDATED] = utcnow()
 
         user = get_user()
-        article['version_creator'] = str(user[config.ID_FIELD])
+        article["version_creator"] = str(user[config.ID_FIELD])
 
-        resolve_document_version(article, ARCHIVE, 'PATCH', article)
+        resolve_document_version(article, ARCHIVE, "PATCH", article)
 
         if article[ITEM_TYPE] == CONTENT_TYPE.COMPOSITE:
             package_service = PackageService()
             item_refs = package_service.get_item_refs(article)
             for ref in item_refs:
-                item_in_package = [item for item in articles_to_kill
-                                   if item.get('item_id', item.get(config.ID_FIELD)) == ref[RESIDREF]]
-                ref['location'] = ARCHIVE
+                item_in_package = [
+                    item for item in articles_to_kill if item.get("item_id", item.get(config.ID_FIELD)) == ref[RESIDREF]
+                ]
+                ref["location"] = ARCHIVE
                 ref[config.VERSION] = item_in_package[0][config.VERSION]
 
     def _get_take_package_id(self, item):
@@ -374,10 +385,13 @@ class ArchivedService(BaseService):
 
         :return: _id of the package or None
         """
-        takes_package = [package.get(PACKAGE) for package in item.get(LINKED_IN_PACKAGES, [])
-                         if package.get(PACKAGE_TYPE) == TAKES_PACKAGE]
+        takes_package = [
+            package.get(PACKAGE)
+            for package in item.get(LINKED_IN_PACKAGES, [])
+            if package.get(PACKAGE_TYPE) == TAKES_PACKAGE
+        ]
         if len(takes_package) > 1:
-            message = 'Multiple takes found for item: {0}'.format(item[config.ID_FIELD])
+            message = "Multiple takes found for item: {0}".format(item[config.ID_FIELD])
             logger.error(message)
         return takes_package[0] if takes_package else None
 
@@ -389,10 +403,10 @@ class ArchivedService(BaseService):
         """
         refs = None
         if package:
-            groups = package.get('groups', [])
-            refs = next((group.get('refs') for group in groups if group['id'] == MAIN_GROUP), None)
+            groups = package.get("groups", [])
+            refs = next((group.get("refs") for group in groups if group["id"] == MAIN_GROUP), None)
 
         return refs
 
 
-superdesk.privilege(name='archived', label='Archive Management', description='User can remove items from the archived')
+superdesk.privilege(name="archived", label="Archive Management", description="User can remove items from the archived")
