@@ -14,26 +14,25 @@ import superdesk
 from .db import DbAuthService
 from .commands import CreateUserCommand, HashUserPasswordsCommand  # noqa
 from superdesk.services import BaseService
-from apps.auth.db.change_password import ChangePasswordService,\
-    ChangePasswordResource
+from apps.auth.db.change_password import ChangePasswordService, ChangePasswordResource
 
 
 def init_app(app):
-    endpoint_name = 'auth_db'
-    service = DbAuthService('auth', backend=superdesk.get_backend())
+    endpoint_name = "auth_db"
+    service = DbAuthService("auth", backend=superdesk.get_backend())
     AuthResource(endpoint_name, app=app, service=service)
 
-    endpoint_name = 'reset_user_password'
+    endpoint_name = "reset_user_password"
     service = ResetPasswordService(endpoint_name, backend=superdesk.get_backend())
     ResetPasswordResource(endpoint_name, app=app, service=service)
 
-    endpoint_name = 'change_user_password'
+    endpoint_name = "change_user_password"
     service = ChangePasswordService(endpoint_name, backend=superdesk.get_backend())
     ChangePasswordResource(endpoint_name, app=app, service=service)
 
-    endpoint_name = 'active_tokens'
+    endpoint_name = "active_tokens"
     service = BaseService(endpoint_name, backend=superdesk.get_backend())
     ActiveTokensResource(endpoint_name, app=app, service=service)
 
 
-superdesk.intrinsic_privilege('auth_db', method=['DELETE'])
+superdesk.intrinsic_privilege("auth_db", method=["DELETE"])
