@@ -15,12 +15,10 @@ from .service import ConceptItemsService
 
 
 def init_app(app):
-    endpoint_name = 'concept_items'
+    endpoint_name = "concept_items"
     service = ConceptItemsService(endpoint_name, backend=superdesk.get_backend())
     ConceptItemsResource(endpoint_name, app=app, service=service)
 
     superdesk.privilege(
-        name=CONCEPT_ITEMS_PRIVELEGE,
-        label='Concept items management',
-        description='User can manage concept items.'
+        name=CONCEPT_ITEMS_PRIVELEGE, label="Concept items management", description="User can manage concept items."
     )
