@@ -17,12 +17,12 @@ logger = logging.getLogger(__name__)
 
 
 def init_app(app):
-    endpoint_name = 'contacts'
+    endpoint_name = "contacts"
     service = ContactsService(endpoint_name, backend=superdesk.get_backend())
     ContactsResource(endpoint_name, app=app, service=service)
-    superdesk.privilege(name=CONTACTS_PRIVILEDGE, label='Contacts Management', description='Manage Contacts')
-    superdesk.privilege(name=VIEW_CONTACTS, label='Contacts View Rights', description='View Contacts')
+    superdesk.privilege(name=CONTACTS_PRIVILEDGE, label="Contacts Management", description="Manage Contacts")
+    superdesk.privilege(name=VIEW_CONTACTS, label="Contacts View Rights", description="View Contacts")
 
     service = OrganisationService(endpoint_name, backend=superdesk.get_backend())
-    endpoint_name = 'contacts organisations'
+    endpoint_name = "contacts organisations"
     OrganisationSearchResource(endpoint_name, app=app, service=service)
