@@ -15,8 +15,8 @@ from apps.keywords.alchemy import AlchemyKeywordsProvider
 
 
 def init_app(app):
-    endpoint_name = 'keywords'
+    endpoint_name = "keywords"
     service = KeywordsService(endpoint_name, backend=superdesk.get_backend())
-    if app.config.get('KEYWORDS_PROVIDER') == 'Alchemy':
+    if app.config.get("KEYWORDS_PROVIDER") == "Alchemy":
         service.provider = AlchemyKeywordsProvider()
     KeywordsResource(endpoint_name, app=app, service=service)
