@@ -15,15 +15,17 @@ from apps.languages.resource import LanguagesResource
 
 
 def init_app(app):
-    endpoint_name = 'languages'
+    endpoint_name = "languages"
     service = LanguagesService(endpoint_name, backend=get_backend())
     LanguagesResource(endpoint_name, app=app, service=service)
 
-    languages = app.config.get('LANGUAGES', [])
+    languages = app.config.get("LANGUAGES", [])
     for language in languages:
-        language['_id'] = language['language']
+        language["_id"] = language["language"]
 
     # add language to aggregations
-    aggregations.update({
-        'language': {'terms': {'field': 'language'}},
-    })
+    aggregations.update(
+        {
+            "language": {"terms": {"field": "language"}},
+        }
+    )
