@@ -16,9 +16,15 @@ from apps.marked_desks.service import MarkedForDesksService
 
 
 def init_app(app):
-    endpoint_name = 'marked_for_desks'
+    endpoint_name = "marked_for_desks"
     service = MarkedForDesksService(endpoint_name, backend=get_backend())
     MarkedForDesksResource(endpoint_name, app=app, service=service)
 
-    superdesk.privilege(name='mark_for_desks', label='Mark items for desks',
-                        description='User can mark items for other desks.')
+    superdesk.privilege(
+        name="mark_for_desks", label="Mark items for desks", description="User can mark items for other desks."
+    )
+    superdesk.privilege(
+        name="mark_for_desks__non_members",
+        label="Mark items for desks even if the user is not a member of the desk",
+        description="User can mark items for other desks even if they are not a member of that desk",
+    )
