@@ -16,14 +16,13 @@ from superdesk.privilege import get_privilege_list
 
 
 class PrivilegeService(superdesk.Service):
-
     def get(self, req, lookup):
         """
         Returns all registered privileges.
         """
 
         _privileges = get_privilege_list()
-        _privileges = sorted(_privileges, key=itemgetter('label'))
+        _privileges = sorted(_privileges, key=itemgetter("label"))
 
         return ListCursor(_privileges)
 
@@ -31,14 +30,14 @@ class PrivilegeService(superdesk.Service):
 class PrivilegeResource(superdesk.Resource):
     """Read-only resource with all privileges."""
 
-    resource_methods = ['GET']
+    resource_methods = ["GET"]
     item_methods = []
     schema = {
-        'name': {'type': 'string'},
-        'label': {'type': 'string'},
-        'description': {'type': 'string'},
+        "name": {"type": "string"},
+        "label": {"type": "string"},
+        "description": {"type": "string"},
     }
 
 
 def init_app(app):
-    PrivilegeResource('privileges', app=app, service=PrivilegeService())
+    PrivilegeResource("privileges", app=app, service=PrivilegeService())
