@@ -1,4 +1,3 @@
-
 from flask_babel import _
 
 from .common import BasePublishResource, ITEM_UNPUBLISH, CONTENT_STATE, ITEM_KILL
@@ -8,6 +7,7 @@ from .kill import KillPublishService, PACKAGE_WORKFLOW
 class UnpublishResource(BasePublishResource):
     def __init__(self, endpoint_name, app, service):
         super().__init__(endpoint_name, app, service, ITEM_UNPUBLISH)
+
     pass
 
 
@@ -16,9 +16,7 @@ class UnpublishService(KillPublishService):
     item_operation = ITEM_UNPUBLISH
     published_state = CONTENT_STATE.UNPUBLISHED
     package_workflow = PACKAGE_WORKFLOW.IGNORE
-    VALIDATE_ERROR_MESSAGE = _(
-        'This item is in a package. It needs to be removed before the item can be unpublished.'
-    )
+    VALIDATE_ERROR_MESSAGE = _("This item is in a package. It needs to be removed before the item can be unpublished.")
 
     def __init__(self, datasource=None, backend=None):
         super().__init__(datasource=datasource, backend=backend)
