@@ -14,6 +14,6 @@ from apps.publish.formatters.resource import FormattersResource
 
 
 def init_app(app):
-    endpoint_name = 'formatters'
+    endpoint_name = "formatters"
     service = FormattersService(endpoint_name, backend=get_backend())
     FormattersResource(endpoint_name, app=app, service=service)
