@@ -20,16 +20,22 @@ logger = logging.getLogger(__name__)
 
 
 def init_app(app):
-    endpoint_name = 'rule_sets'
+    endpoint_name = "rule_sets"
     service = RuleSetsService(endpoint_name, backend=get_backend())
     RuleSetsResource(endpoint_name, app=app, service=service)
 
-    endpoint_name = 'routing_schemes'
+    endpoint_name = "routing_schemes"
     service = RoutingRuleSchemeService(endpoint_name, backend=get_backend())
     RoutingRuleSchemeResource(endpoint_name, app=app, service=service)
 
-    superdesk.privilege(name='rule_sets', label='Transformation Rules Management',
-                        description='User can setup transformation rules for ingest content.')
+    superdesk.privilege(
+        name="rule_sets",
+        label="Transformation Rules Management",
+        description="User can setup transformation rules for ingest content.",
+    )
 
-    superdesk.privilege(name='routing_rules', label='Routing Rules Management',
-                        description='User can manage routing rules which are executed on ingested articles.')
+    superdesk.privilege(
+        name="routing_rules",
+        label="Routing Rules Management",
+        description="User can manage routing rules which are executed on ingested articles.",
+    )
