@@ -10,7 +10,11 @@
 
 import superdesk
 
-from apps.search_providers.registry import registered_search_providers, allowed_search_providers, register_search_provider  # noqa
+from apps.search_providers.registry import (
+    registered_search_providers,
+    allowed_search_providers,
+    register_search_provider,
+)  # noqa
 from apps.search_providers.resource import SearchProviderResource
 from apps.search_providers.service import SearchProviderService
 from apps.search_providers.registry import SearchProviderAllowedResource, SearchProviderAllowedService
@@ -18,26 +22,17 @@ from apps.search_providers.registry import SearchProviderAllowedResource, Search
 
 def init_app(app):
     from apps.search_providers.proxy import SearchProviderProxyResource, SearchProviderProxyService
+
     superdesk.privilege(
-        name='search_providers',
-        label='Manage Search Providers',
-        description='User can manage search providers.'
+        name="search_providers", label="Manage Search Providers", description="User can manage search providers."
+    )
+
+    superdesk.register_resource(name="search_providers", resource=SearchProviderResource, service=SearchProviderService)
+
+    superdesk.register_resource(
+        name="search_providers_proxy", resource=SearchProviderProxyResource, service=SearchProviderProxyService
     )
 
     superdesk.register_resource(
-        name='search_providers',
-        resource=SearchProviderResource,
-        service=SearchProviderService
-    )
-
-    superdesk.register_resource(
-        name='search_providers_proxy',
-        resource=SearchProviderProxyResource,
-        service=SearchProviderProxyService
-    )
-
-    superdesk.register_resource(
-        name='search_providers_allowed',
-        resource=SearchProviderAllowedResource,
-        service=SearchProviderAllowedService
+        name="search_providers_allowed", resource=SearchProviderAllowedResource, service=SearchProviderAllowedService
     )
