@@ -19,7 +19,7 @@ def init_app(app):
     :param app:
     :return:
     """
-    endpoint_name = 'api_audit'
+    endpoint_name = "api_audit"
 
     service = ApiAuditService(endpoint_name, backend=superdesk.get_backend())
     ApiAuditResource(endpoint_name, app=app, service=service)
