@@ -14,6 +14,6 @@ from superdesk.services import BaseService
 
 
 def init_app(app):
-    endpoint_name = 'companies'
+    endpoint_name = "companies"
     service = BaseService(endpoint_name, backend=superdesk.get_backend())
     CompaniesResource(endpoint_name, app=app, service=service)
