@@ -19,6 +19,6 @@ def init_app(app):
     :param app: the API application object
     :type app: `Eve`
     """
-    endpoint_name = 'items'
+    endpoint_name = "items"
     service = ItemsService(endpoint_name, backend=superdesk.get_backend())
     ItemsResource(endpoint_name, app=app, service=service)
