@@ -19,6 +19,6 @@ def init_app(app):
     :param app: the API application object
     :type app: `Eve`
     """
-    endpoint_name = 'packages'
+    endpoint_name = "packages"
     service = PackagesService(endpoint_name, backend=superdesk.get_backend())
     PackagesResource(endpoint_name, app=app, service=service)
