@@ -20,6 +20,6 @@ def init_app(app):
     :param app: the API application object
     :type app: `Eve`
     """
-    endpoint_name = 'content_api'
+    endpoint_name = "content_api"
     service = PublishService(endpoint_name, backend=superdesk.get_backend())
     PublishResource(endpoint_name, app=app, service=service)
