@@ -19,5 +19,5 @@ def init_app(app):
     :param app: the API application object
     :type app: `Eve`
     """
-    service = ContactsService(datasource='contacts', backend=superdesk.get_backend())
-    ContactsResource(endpoint_name='contacts', app=app, service=service)
+    service = ContactsService(datasource="contacts", backend=superdesk.get_backend())
+    ContactsResource(endpoint_name="contacts", app=app, service=service)
