@@ -19,7 +19,7 @@ log = logging.getLogger(__name__)
 
 
 def init_app(app):
-    endpoint_name = 'audit'
+    endpoint_name = "audit"
 
     service = AuditService(endpoint_name, backend=superdesk.get_backend())
     AuditResource(endpoint_name, app=app, service=service)
