@@ -9,6 +9,7 @@ from .places_autocomplete import PlacesAutocompleteResource, PlacesAutocompleteS
 
 
 def init_app(app):
-    if app.config.get('GEONAMES_USERNAME'):
-        superdesk.register_resource('places_autocomplete', PlacesAutocompleteResource, PlacesAutocompleteService,
-                                    _app=app)
+    if app.config.get("GEONAMES_USERNAME"):
+        superdesk.register_resource(
+            "places_autocomplete", PlacesAutocompleteResource, PlacesAutocompleteService, _app=app
+        )
